/*
 * This file is part of Skyward Hub.
 *
 * Skyward Hub is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * Skyward Hub is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * Skyward Hub. If not, see <https://www.gnu.org/licenses/>.
 *
 */

#pragma once

#include <QStandardPaths>
#include <QString>

namespace SkywardHubStrings
{

static const QString defaultConfigurationFolder =
    QStandardPaths::standardLocations(QStandardPaths::AppDataLocation).first() +
    "/" + "SkywardHub";
static const QString defaultSettingsFilePath =
    defaultConfigurationFolder + "/" + "settings.xml";
static const QString defaultLogsFolder =
    defaultConfigurationFolder + "/" + "Logs";
static const QString defaultStreamFile =
    defaultConfigurationFolder + "/" + "StreamFile.txt";
static const QString defaultPrefabsFolder =
    defaultConfigurationFolder + "/" + "Profiles" + "/";
static const QString defaultConfigurationFileName = "default.xml";
static const QString defaultConfigurationIconPath =
    defaultConfigurationFolder + "/" + "defaultConfigIcon.svg";

// Xml Tags Name
static const QString skywardHubInitFileTag             = "LoadOnLaunch";
static const QString settingsObjectName                = "Settings";
static const QString configurationNameAttribute        = "name";
static const QString configurationNameValue            = "configuration";
static const QString configurationIconPathAttribute    = "configuration_icon";
static const QString configurationDescriptionAttribute = "description";

// Output Messages
static const QString settingsSavedCorrectlyMsg = "Settings saved";
static const QString serialPortClosedErrorMsg =
    "Mavlink >> Error, Serial port closed, impossible to write msg";
static const QString imageViewerInfo =
    "Double click on a label to open the settings panel";

// Topics
static const QString commandsTopic                = "TelemetryCommand";
static const QString treeViewerReceivingBaseTopic = "TreeViewer";

static const QString logCommandsTopic                  = "LogCommands";
static const QString raw_event_id                      = "event_id";
static const QString raw_event_topic_id                = "topic_id";
static const QString mavlink_orientation_tc_yaw_name   = "yaw";
static const QString mavlink_orientation_tc_pitch_name = "pitch";
static const QString mavlink_orientation_tc_roll_name  = "roll";
static const QString mavlink_quality_link_topic        = "MavlinkLinkQuality";
static const QString mavlink_received_msg_topic        = "Mav";
static const QString mavlink_initial_coordinates_tc_latitude_name = "latitude";
static const QString mavlink_initial_coordinates_tc_longitude_name =
    "longitude";

static const QString mavlink_received_msg_ACK_topic =
    mavlink_received_msg_topic + "/ACK_TM";
static const QString mavlink_received_msg_NACK_topic =
    mavlink_received_msg_topic + "/NACK_TM";

static const QString mavlink_system_id_name    = "system_id";
static const QString mavlink_component_id_name = "component_id";

// Themes
static const QString defaultThemesFolderPath =
    defaultConfigurationFolder + "/" + "Themes";
static const QString defaultThemeFilePath = ":/assets/styles/global.qss";
static const QMap<QString, QString> defaultThemes{
    {"Default", ":/assets/styles/global.qss"},
    {"White Mode", ":/assets/styles/white-mode.qss"}};
};  // namespace SkywardHubStrings
